==> zio-aws-ec2_2.12-5.19.12.1-sources.jar: zio/aws/ec2/model/DescribeNetworkAclsRequest.scala <==
package zio.aws.ec2.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.ec2.model.primitives.{
  DescribeNetworkAclsMaxResults,
  NetworkAclId
}
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class DescribeNetworkAclsRequest(
    filters: Optional[Iterable[zio.aws.ec2.model.Filter]] = Optional.Absent,
    networkAclIds: Optional[Iterable[NetworkAclId]] = Optional.Absent,
    nextToken: Optional[String] = Optional.Absent,
    maxResults: Optional[DescribeNetworkAclsMaxResults] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DescribeNetworkAclsRequest = {
    import DescribeNetworkAclsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DescribeNetworkAclsRequest
      .builder()
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(
        networkAclIds.map(value =>
          value.map { item =>
            NetworkAclId.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.networkAclIds)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .optionallyWith(
        maxResults.map(value =>
          DescribeNetworkAclsMaxResults.unwrap(value): Integer
        )
      )(_.maxResults)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.DescribeNetworkAclsRequest.ReadOnly =
    zio.aws.ec2.model.DescribeNetworkAclsRequest.wrap(buildAwsValue())
}
object DescribeNetworkAclsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DescribeNetworkAclsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.DescribeNetworkAclsRequest =
      zio.aws.ec2.model.DescribeNetworkAclsRequest(
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        networkAclIds.map(value => value),
        nextToken.map(value => value),
        maxResults.map(value => value)
      )
    def filters: Optional[List[zio.aws.ec2.model.Filter.ReadOnly]]
    def networkAclIds: Optional[List[NetworkAclId]]
    def nextToken: Optional[String]
    def maxResults: Optional[DescribeNetworkAclsMaxResults]
    def getFilters
        : ZIO[Any, AwsError, List[zio.aws.ec2.model.Filter.ReadOnly]] =
      AwsError.unwrapOptionField("filters", filters)
    def getNetworkAclIds: ZIO[Any, AwsError, List[NetworkAclId]] =
      AwsError.unwrapOptionField("networkAclIds", networkAclIds)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, DescribeNetworkAclsMaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DescribeNetworkAclsRequest
  ) extends zio.aws.ec2.model.DescribeNetworkAclsRequest.ReadOnly {
    override val filters: Optional[List[zio.aws.ec2.model.Filter.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.filters())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.Filter.wrap(item)
          }.toList
        )
    override val networkAclIds: Optional[List[NetworkAclId]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.networkAclIds())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.primitives.NetworkAclId(item)
          }.toList
        )
    override val nextToken: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => value: String)
    override val maxResults: Optional[DescribeNetworkAclsMaxResults] =
      zio.aws.core.internal
        .optionalFromNullable(impl.maxResults())
        .map(value =>
          zio.aws.ec2.model.primitives.DescribeNetworkAclsMaxResults(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DescribeNetworkAclsRequest
  ): zio.aws.ec2.model.DescribeNetworkAclsRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.12-7.21.15.11-sources.jar: zio/aws/ec2/model/DescribeNetworkAclsRequest.scala <==
package zio.aws.ec2.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.ec2.model.primitives.{
  DescribeNetworkAclsMaxResults,
  NetworkAclId
}
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class DescribeNetworkAclsRequest(
    filters: Optional[Iterable[zio.aws.ec2.model.Filter]] = Optional.Absent,
    dryRun: Optional[Boolean] = Optional.Absent,
    networkAclIds: Optional[Iterable[NetworkAclId]] = Optional.Absent,
    nextToken: Optional[String] = Optional.Absent,
    maxResults: Optional[DescribeNetworkAclsMaxResults] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DescribeNetworkAclsRequest = {
    import DescribeNetworkAclsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DescribeNetworkAclsRequest
      .builder()
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .optionallyWith(
        networkAclIds.map(value =>
          value.map { item =>
            NetworkAclId.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.networkAclIds)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .optionallyWith(
        maxResults.map(value =>
          DescribeNetworkAclsMaxResults.unwrap(value): Integer
        )
      )(_.maxResults)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.DescribeNetworkAclsRequest.ReadOnly =
    zio.aws.ec2.model.DescribeNetworkAclsRequest.wrap(buildAwsValue())
}
object DescribeNetworkAclsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DescribeNetworkAclsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.DescribeNetworkAclsRequest =
      zio.aws.ec2.model.DescribeNetworkAclsRequest(
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        dryRun.map(value => value),
        networkAclIds.map(value => value),
        nextToken.map(value => value),
        maxResults.map(value => value)
      )
    def filters: Optional[List[zio.aws.ec2.model.Filter.ReadOnly]]
    def dryRun: Optional[Boolean]
    def networkAclIds: Optional[List[NetworkAclId]]
    def nextToken: Optional[String]
    def maxResults: Optional[DescribeNetworkAclsMaxResults]
    def getFilters
        : ZIO[Any, AwsError, List[zio.aws.ec2.model.Filter.ReadOnly]] =
      AwsError.unwrapOptionField("filters", filters)
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
    def getNetworkAclIds: ZIO[Any, AwsError, List[NetworkAclId]] =
      AwsError.unwrapOptionField("networkAclIds", networkAclIds)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, DescribeNetworkAclsMaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DescribeNetworkAclsRequest
  ) extends zio.aws.ec2.model.DescribeNetworkAclsRequest.ReadOnly {
    override val filters: Optional[List[zio.aws.ec2.model.Filter.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.filters())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.Filter.wrap(item)
          }.toList
        )
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
    override val networkAclIds: Optional[List[NetworkAclId]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.networkAclIds())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.primitives.NetworkAclId(item)
          }.toList
        )
    override val nextToken: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => value: String)
    override val maxResults: Optional[DescribeNetworkAclsMaxResults] =
      zio.aws.core.internal
        .optionalFromNullable(impl.maxResults())
        .map(value =>
          zio.aws.ec2.model.primitives.DescribeNetworkAclsMaxResults(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DescribeNetworkAclsRequest
  ): zio.aws.ec2.model.DescribeNetworkAclsRequest.ReadOnly = new Wrapper(impl)
}
